==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/equipment/zapper/ShootableGadgetItemMethods.java <==
package com.zurrtum.create.content.equipment.zapper;

import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.infrastructure.packet.s2c.ShootGadgetPacket;

import java.util.function.Function;
import java.util.function.Predicate;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_243;
import net.minecraft.class_3222;

public class ShootableGadgetItemMethods {

    public static void applyCooldown(class_1657 player, class_1799 item, class_1268 hand, Predicate<class_1799> predicate, int cooldown) {
        if (cooldown <= 0)
            return;

        boolean gunInOtherHand = predicate.test(player.method_5998(hand == class_1268.field_5808 ? class_1268.field_5810 : class_1268.field_5808));
        player.method_7357().method_62835(item, gunInOtherHand ? cooldown * 2 / 3 : cooldown);
    }

    public static void sendPackets(class_1657 player, Function<Boolean, ? extends ShootGadgetPacket> factory) {
        if (!(player instanceof class_3222 serverPlayer))
            return;
        serverPlayer.method_51469().method_14178().method_18754(player, factory.apply(false));
        serverPlayer.field_13987.method_14364(factory.apply(true));
    }

    public static boolean shouldSwap(class_1657 player, class_1799 item, class_1268 hand, Predicate<class_1799> predicate) {
        boolean isSwap = item.method_57826(AllDataComponents.SHAPER_SWAP);
        boolean mainHand = hand == class_1268.field_5808;
        boolean gunInOtherHand = predicate.test(player.method_5998(mainHand ? class_1268.field_5810 : class_1268.field_5808));

        // Pass To Offhand
        if (mainHand && isSwap && gunInOtherHand)
            return true;
        if (mainHand && !isSwap && gunInOtherHand)
            item.method_57379(AllDataComponents.SHAPER_SWAP, true);
        if (!mainHand && isSwap)
            item.method_57381(AllDataComponents.SHAPER_SWAP);
        if (!mainHand && gunInOtherHand)
            player.method_5998(class_1268.field_5808).method_57381(AllDataComponents.SHAPER_SWAP);
        player.method_6019(hand);
        return false;
    }

    public static class_243 getGunBarrelVec(class_1657 player, boolean mainHand, class_243 rightHandForward) {
        class_243 start = player.method_73189().method_1031(0, player.method_5751(), 0);
        float yaw = (float) ((player.method_36454()) / -180 * Math.PI);
        float pitch = (float) ((player.method_36455()) / -180 * Math.PI);
        int flip = mainHand == (player.method_6068() == class_1306.field_6183) ? -1 : 1;
        class_243 barrelPosNoTransform = new class_243(flip * rightHandForward.field_1352, rightHandForward.field_1351, rightHandForward.field_1350);
        class_243 barrelPos = start.method_1019(barrelPosNoTransform.method_1037(pitch).method_1024(yaw));
        return barrelPos;
    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/equipment/zapper/ShootableGadgetItemMethods.java <==
package com.zurrtum.create.content.equipment.zapper;

import com.zurrtum.create.AllDataComponents;
import java.util.function.Function;
import java.util.function.Predicate;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_243;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_3222;

public class ShootableGadgetItemMethods {

    public static void applyCooldown(class_1657 player, class_1799 item, class_1268 hand, Predicate<class_1799> predicate, int cooldown) {
        if (cooldown <= 0)
            return;

        boolean gunInOtherHand = predicate.test(player.method_5998(hand == class_1268.field_5808 ? class_1268.field_5810 : class_1268.field_5808));
        player.method_7357().method_62835(item, gunInOtherHand ? cooldown * 2 / 3 : cooldown);
    }

    public static void sendPackets(class_1657 player, Function<Boolean, class_2596<class_2602>> factory) {
        if (!(player instanceof class_3222 serverPlayer))
            return;
        serverPlayer.method_51469().method_14178().method_18754(player, factory.apply(false));
        serverPlayer.field_13987.method_14364(factory.apply(true));
    }

    public static boolean shouldSwap(class_1657 player, class_1799 item, class_1268 hand, Predicate<class_1799> predicate) {
        boolean isSwap = item.method_57826(AllDataComponents.SHAPER_SWAP);
        boolean mainHand = hand == class_1268.field_5808;
        boolean gunInOtherHand = predicate.test(player.method_5998(mainHand ? class_1268.field_5810 : class_1268.field_5808));

        // Pass To Offhand
        if (mainHand && isSwap && gunInOtherHand)
            return true;
        if (mainHand && !isSwap && gunInOtherHand)
            item.method_57379(AllDataComponents.SHAPER_SWAP, true);
        if (!mainHand && isSwap)
            item.method_57381(AllDataComponents.SHAPER_SWAP);
        if (!mainHand && gunInOtherHand)
            player.method_5998(class_1268.field_5808).method_57381(AllDataComponents.SHAPER_SWAP);
        player.method_6019(hand);
        return false;
    }

    public static class_243 getGunBarrelVec(class_1657 player, boolean mainHand, class_243 rightHandForward) {
        class_243 start = player.method_73189().method_1031(0, player.method_5751(), 0);
        float yaw = (float) ((player.method_36454()) / -180 * Math.PI);
        float pitch = (float) ((player.method_36455()) / -180 * Math.PI);
        int flip = mainHand == (player.method_6068() == class_1306.field_6183) ? -1 : 1;
        class_243 barrelPosNoTransform = new class_243(flip * rightHandForward.field_1352, rightHandForward.field_1351, rightHandForward.field_1350);
        class_243 barrelPos = start.method_1019(barrelPosNoTransform.method_1037(pitch).method_1024(yaw));
        return barrelPos;
    }

}
